@@ -56,8 +56,8 @@ class Model:
             "namespace": "",
         },
     )
-    pose: "Model.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Model.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -142,8 +142,8 @@ class Model:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Model.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Model.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -168,7 +168,7 @@ class Model:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -191,7 +191,7 @@ class Model:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -271,8 +271,8 @@ class Model:
                 "namespace": "",
             },
         )
-        pose: "Model.Link.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Model.Link.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -301,8 +301,8 @@ class Model:
                 attached to.
             """
 
-            pose: "Model.Link.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["Model.Link.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -328,7 +328,7 @@ class Model:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -351,7 +351,7 @@ class Model:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -385,7 +385,7 @@ class State:
     class Meta:
         name = "state"
 
-    sim_time: float = field(
+    sim_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -393,7 +393,7 @@ class State:
             "required": True,
         },
     )
-    wall_time: float = field(
+    wall_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -401,7 +401,7 @@ class State:
             "required": True,
         },
     )
-    real_time: float = field(
+    real_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -519,8 +519,8 @@ class State:
                 "namespace": "",
             },
         )
-        pose: "State.Light.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["State.Light.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -549,8 +549,8 @@ class State:
                 attached to.
             """
 
-            pose: "State.Light.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["State.Light.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -576,7 +576,7 @@ class State:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -599,7 +599,7 @@ class State:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
